#!/usr/bin/python

"""
# apply sigma values to h strips

# take sigma values for each grid cell previously calculated with make_sigma.py,
# multiply that with each h strip to produce sigma*h, and store that result.
"""

from __future__ import print_function

import sys
import os
import datetime
import shutil
import optparse
import numpy

import utils



parser = optparse.OptionParser(usage='%prog [options] sigma_file', description="Multiply sigma with H strip files to get Hsigma. ")
parser.add_option('-b', '--binary', action="store_true", default=False, help="Write Hsigma files in binary format instead of default numpy savez file.")
parser.add_option('-c', '--config', default="config.ini", help="set configuration file to use.  Default is 'config.ini'")

options, args = parser.parse_args()


if len(args) != 1:
	parser.print_usage()
	sys.exit()


sigmafile = args[0]


config = utils.getConfig(options.config)
ntimesteps = config["ntimesteps"]

try:
	sigma = numpy.load(sigmafile)
except:
	try:
		landmask = numpy.load(config["landmask_file"])
		sigma = utils.getSpriorNetcdf(sigmafile, "sigma", landmask)
	except:
		sys.exit("Error reading sigma file.")


# set the directory where the Hsigma slices will be stored.
hsigdir = config["workdir"] + "/" + config["hsigdir"]
if os.path.exists(hsigdir):
	# remove any files in the hdir.
	shutil.rmtree(hsigdir)

# create the h directory
try:
	os.makedirs(hsigdir)
except:
	sys.exit("Can't make directory for hsigma files: %s" % hsigdir)

t1 = datetime.datetime.now()

for j in range(ntimesteps):

	# h slice files are numbered 1 .. ntimesteps
	h = utils.read_sparse_h(j, config)

	b = numpy.multiply(h.todense(), sigma[j])
	b = numpy.array(b)	# convert from matrix to array

	hsigfile = hsigdir + "/H%04d.npz" % (j+1)
	if options.binary:
		utils.binwrite_sparse(hsigfile, b)
	else:
		utils.write_sparse(hsigfile, b)

	t2 = datetime.datetime.now()
	print(j, "of", ntimesteps-1, hsigfile, t2 - t1)
